@@ -14,17 +14,17 @@ from os_vif.internal.command.ip import api
 
 
 def set(device, check_exit_code=None, state=None, mtu=None, address=None,
-        promisc=None):
+        promisc=None, master=None):
     """Method to set a parameter in an interface."""
     return api.ip.set(device, check_exit_code=check_exit_code, state=state,
-                      mtu=mtu, address=address, promisc=promisc)
+                      mtu=mtu, address=address, promisc=promisc, master=master)
 
 
 def add(device, dev_type, check_exit_code=None, peer=None, link=None,
-        vlan_id=None):
+        vlan_id=None, ageing=None):
     """Method to add an interface."""
     return api.ip.add(device, dev_type, check_exit_code=check_exit_code,
-                      peer=peer, link=link, vlan_id=vlan_id)
+                      peer=peer, link=link, vlan_id=vlan_id, ageing=ageing)
 
 
 def delete(device, check_exit_code=None):
